"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
var light = "light";
var regular = "regular";
var condensed = "condensed";

var tvFontSPs = {
  contentTitle1: {
    size: 36,
    type: light,
    match: "h2"
  },
  contentTitle2: {
    size: 24,
    type: light,
    match: "h4"
  },
  browseLaneTitle: {
    size: 20,
    type: condensed,
    match: "h5"
  },
  subhead: {
    size: 16,
    type: regular,
    match: "subtitle1"
  },
  button: {
    size: 14,
    type: condensed,
    match: "button"
  },
  body: {
    size: 14,
    type: regular,
    match: "body1"
  },
  listItem: {
    size: 14,
    type: condensed + regular
    // match: 'body1'
  },
  cardText: {
    size: 14,
    type: condensed + regular
    // match: 'body1'
  },
  secondaryText: {
    size: 12,
    type: condensed + regular,
    match: "body2"
  }
};

var tvFontSPsEntries = Object.entries(tvFontSPs); // cache it once

var findMatch = function findMatch(t) {
  var e = tvFontSPsEntries.find(function (x) {
    return x[1].match === t;
  });
  if (e) return e[1];
  return null;
};

var spToRem = function spToRem(value, scale) {
  return value * 0.0625 * scale + "rem";
};

var modifyRem = function modifyRem(value, scale) {
  return parseFloat(value) * scale + "rem";
};

var getTVTypographyConfig = function getTVTypographyConfig(defaultTheme) {
  var iw = window.innerWidth;
  var scale = iw >= defaultTheme.breakpoints.values.lg ? iw >= defaultTheme.breakpoints.values.xl ? 1.50 : 1.20 : 1;
  console.error('scale', scale);
  var typography = Object.assign({}, defaultTheme.typography);
  for (var o in typography) {
    // console.warn(o, typography[o]);
    if (!typography[o].fontSize) continue;
    var m = findMatch(o);
    var fontSize = void 0;
    if (m) {
      fontSize = spToRem(m.size, scale);
      // console.log(o, 'match', fontSize, typography[o].fontSize, scale);
      typography[o].fontSize = fontSize;
      typography[o].lineHeight = typography[o].lineHeight * (scale - .1);
    } else {
      fontSize = modifyRem(typography[o].fontSize, scale);
      // console.log(o, 'no-match', fontSize, typography[o].fontSize, scale);
      typography[o].fontSize = fontSize;
      typography[o].lineHeight = typography[o].lineHeight * (scale - .1);
    }
    delete typography[o].color;
  }

  var overrides = {
    MuiInputBase: {
      input: {
        fontSize: typography.subtitle1.fontSize
      },
      root: {
        lineHeight: typography.subtitle1.lineHeight
      }
    },
    MuiSelect: {
      select: {
        height: typography.subtitle1.lineHeight + "rem"
      }
    },
    MuiFormLabel: {
      root: {
        // fontSize: typography.caption.fontSize,
        // lineHeight: typography.caption.lineHeight
      }
    }
  };

  return { typography: typography, overrides: overrides };
};

exports.default = getTVTypographyConfig;
module.exports = exports.default;