import React, { Component } from "react";
import { HashRouter as Router, Route, Link } from "react-router-dom";

import { MuiThemeProvider, createMuiTheme } from "@material-ui/core/styles";

import BrowseDemo from "components/demo/BrowseDemo";
import ConsumptionDemo from "components/demo/ConsumptionDemo";
import ConsumptionArtworkDemo from "components/demo/ConsumptionArtworkDemo";
import ConsumptionAutoDemo from "components/demo/ConsumptionAutoDemo";
import DetailsDemo from "components/demo/DetailsDemo";
import SearchDemo from "components/demo/SearchDemo";

import indigo from "@material-ui/core/colors/indigo";
import amber from "@material-ui/core/colors/amber";
import getTypographyConfig from './TVTypographyConfig';

import "./App.css";

const DemoMain = props => {
  return (
    <React.Fragment>
      <Link to="/browse">Browse Page</Link>
      <br />
      <Link to="/detail">Detail Page</Link>
      <br />
      <Link to="/media">Consumption Page</Link>
      <br /> <Link to="/mediaArtwork">Consumption with Artwork Page</Link>
      <br />
      <Link to="/auto/media">Consumption Auto Page</Link>
      <br />
      <Link to="/search">Search Page</Link>
      <br />
    </React.Fragment>
  );
};

class App extends Component {
  constructor(props) {
    super(props);
    this.state = { ih: window.innerHeight };
  }

  componentDidMount() {
    window.addEventListener("resize", this.onResize);
  }

  onResize = evt => {
    this.setState({ ih: window.innerHeight });
  };

  render() {
    var { ih } = this.state;

    const defaultTheme = createMuiTheme({typography: {useNextVariants: true} });
    const {typography, overrides} = getTypographyConfig(defaultTheme);
    const theme = createMuiTheme({typography, overrides});
      
    return (
      <MuiThemeProvider theme={theme}>
        <div className="App">
          <Router basename="/">
            <React.Fragment>
              <Route exact={true} path="/" component={DemoMain} />
              <Route path="/browse" component={BrowseDemo} />
              <Route path="/detail" component={DetailsDemo} />
              <Route path="/media" component={ConsumptionDemo} />
              <Route path="/mediaArtwork" component={ConsumptionArtworkDemo} />
              <Route path="/auto/media" component={ConsumptionAutoDemo} />
              <Route path="/search" component={SearchDemo} />
            </React.Fragment>
          </Router>
        </div>
      </MuiThemeProvider>
    );
  }
}

export default App;
