const light = "light";
const regular = "regular";
const condensed = "condensed";

const tvFontSPs = {
  contentTitle1: {
    size: 36,
    type: light,
    match: "h2"
  },
  contentTitle2: {
    size: 24,
    type: light,
    match: "h4"
  },
  browseLaneTitle: {
    size: 20,
    type: condensed,
    match: "h5"
  },
  subhead: {
    size: 16,
    type: regular,
    match: "subtitle1"
  },
  button: {
    size: 14,
    type: condensed,
    match: "button"
  },
  body: {
    size: 14,
    type: regular,
    match: "body1"
  },
  listItem: {
    size: 14,
    type: condensed + regular
    // match: 'body1'
  },
  cardText: {
    size: 14,
    type: condensed + regular
    // match: 'body1'
  },
  secondaryText: {
    size: 12,
    type: condensed + regular,
    match: "body2"
  }
};

const tvFontSPsEntries = Object.entries(tvFontSPs); // cache it once

const findMatch = (t) => {
  var e = tvFontSPsEntries.find((x) => {
    return x[1].match === t;
  });
  if (e) return e[1];
  return null;
}

const spToRem = (value, scale) => {
  return `${value * 0.0625 * scale}rem`;
};

const modifyRem = (value, scale) => {
  return `${parseFloat(value) * scale}rem`;
};

const getTVTypographyConfig = (defaultTheme) => {
  const iw = window.innerWidth;
  const scale =
    iw >= defaultTheme.breakpoints.values.lg
      ? iw >= defaultTheme.breakpoints.values.xl
        ? 1.50
        : 1.20
      : 1;
      console.error('scale', scale);
  const typography = Object.assign({}, defaultTheme.typography);
  for (const o in typography) {
    // console.warn(o, typography[o]);
    if (!typography[o].fontSize) continue;
    const m = findMatch(o);
    let fontSize;
    if (m) {
      fontSize = spToRem(m.size, scale);
      // console.log(o, 'match', fontSize, typography[o].fontSize, scale);
      typography[o].fontSize = fontSize;
      typography[o].lineHeight = typography[o].lineHeight * (scale-.1);
    } else {
      fontSize = modifyRem(typography[o].fontSize, scale);
      // console.log(o, 'no-match', fontSize, typography[o].fontSize, scale);
      typography[o].fontSize = fontSize;
      typography[o].lineHeight = typography[o].lineHeight * (scale-.1);
    }
    delete typography[o].color;
  }

  const overrides = {
    MuiInputBase: {
      input: {
        fontSize: typography.subtitle1.fontSize,
      },
      root:  {
        lineHeight: typography.subtitle1.lineHeight
      }
    },
    MuiSelect: {
      select: {
        height: typography.subtitle1.lineHeight + "rem"
      }
    },
    MuiFormLabel: {
      root: {
        // fontSize: typography.caption.fontSize,
        // lineHeight: typography.caption.lineHeight
      }
    }
  };

  return {typography, overrides};
};

export default getTVTypographyConfig;
